@@ -1,6 +1,9 @@
 package TestAdoptCAF;
 
-use base 'Class::Accessor::Fast';
+use Class::Accessor::Fast;
+BEGIN {
+  our @ISA = qw(Class::Accessor::Fast);
+}
 
 __PACKAGE__->mk_accessors('foo');
 __PACKAGE__->mk_ro_accessors('bar');
